#
# spec file for package python-OWSLib
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2015 Angelos Tzotsos <tzotsos@opensuse.org>
# Copyright (c) 2021 Ioda-Net Sàrl, Bruno Friedmann, Charmoille, Switzerland.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %{suse_version} >= 1550
%bcond_without test
%else
# we can't use and test the broken pyproj 3.0 together with libproj in Application:Geo, but
# a live install on 15.3 with pyproj 2.X from the main repo should work.
%bcond_with test
%endif
%{?!python_module:%define python_module() python3-%{**}}
%define         oldpython python
%define         skip_python2 1
%define         skip_python36 1
Name:           python-OWSLib
Version:        0.25.0
Release:        bp155.2.11
Summary:        Python interface to OGC Web Services
License:        BSD-3-Clause
Group:          Productivity/Scientific/Other
URL:            http://geopython.github.io/OWSLib/
# get the test suite form Github
Source:         https://github.com/geopython/OWSLib/archive/refs/tags/%{version}.tar.gz#/OWSLib-%{version}-gh.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
%if %{suse_version >= 1550}
Requires:       python-pyproj >= 2
%else
# see comment above
Requires:       (python-pyproj >= 2 with python-pyproj < 3)
%endif
Requires:       python-python-dateutil >= 1.5
Requires:       python-pytz
Requires:       python-requests >= 1.0
Provides:       python-owslib = %{version}
Obsoletes:      python-owslib < %{version}
%if %{with test}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pyproj >= 2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 1.5}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests >= 1.0}
%endif
BuildArch:      noarch
%python_subpackages

%description
OWSLib is a Python package for client programming with Open Geospatial
Consortium (OGC) web service (hence OWS) interface standards, and their
related content models.

%prep
%setup -q -n OWSLib-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%if %{with test}
%check
# override tox.ini: no doctest no cov, register own mark
echo '[pytest]
markers =
    online
' > pytest.ini
# don't be too picky about failing tests. Upstreams CI is failing too.
# wfs: pyproj complaints about no db context
donttest+="test_ows_interfaces_wfs"
donttest+=" or (TestOffline  and test_wfs_100_noremotemd_parse_all)"
donttest+=" or (TestOffline  and test_wfs_100_noremotemd_parse_single)"
donttest+=" or (TestOffline  and test_wfs_100_noremotemd_parse_none)"
donttest+=" or (TestOffline  and test_wfs_110_remotemd_parse_all)"
donttest+=" or (TestOffline  and test_wfs_110_remotemd_parse_single)"
donttest+=" or (TestOffline  and test_wfs_200_remotemd_parse_all)"
donttest+=" or (TestOffline  and test_wfs_200_remotemd_parse_single)"
donttest+=" or (TestOffline  and test_wms_130_remotemd_parse_all)"
donttest+=" or (TestOffline  and test_wms_130_remotemd_parse_single)"
# online but not marked
donttest+=" or test_wmts_example_informatievlaanderen"
%pytest -s -m "not online" -k "not ($donttest)"
%endif

%files %python_files
%doc AUTHORS.rst CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/owslib
%{python_sitelib}/OWSLib-%{version}*-info

%changelog
* Fri Dec  3 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.25.0
  * WMS: include custom headers (#763)
  * ISO: add MD_BrowseGraphic support (#757)
  * OGC API: fix bbox handling #779), request/response handling
  * WFS: add support for topological filters (#780)
  * various bug fixes
- Release notes for 0.24.1
  * fix CSW request byte handling (#776)
- Release notes for 0.24.0
  * CSW: add CSW 3 client (#746)
  * CSW: add support for distributed search (#771)
  * OGC API: refactor collections for broader use (#753)
  * OACov: add support for scaling (#756)
  * Auth: make most Authentication attributes private (#770)
  * various bug fixes
- Don't test on Leap
* Tue Apr 20 2021 Ben Greiner <code@bnavigator.de>
- Disable python36 build: pyproj not available
- Enable test suite (at least a part of it)
* Sat Feb 13 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.23.0
  * WMS: Handle empty <DataURL>.<Format> element in
    GetCapabilities (#739)
  * WCS: Feature/wcs headers integration (#741)
  * Tests: fix WFS tests (#743)
  * Auth: Support requests AuthBase in addition to basic password
    authentication (#724)
  * WCS: Fix bug with timeout not assigned (#738)
  * Tests: restore ISO GM03 tests as pytests (#734)
  * ISO: OWS/ISO metadata updates (#736)
  * ISO: add support for ISO 19115 keyword thesaurus URLs via
    gmx:Anchor (#735)
  * ISO: fix reference (#733)
- Changes in 0.22.0
  * Tests: Fix tests coveralls (#732)
  * WCS, WFS: Add timeout to get capabilities (#730)
  * Tests: migrate to GitHub actions (#727)
  * ISO: add support for ISO 19115-2 (#726)
- Fix malformed python_module line
* Thu Jan 21 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Depend on python-PyYAML instead of python-pyyaml
* Tue Jan 19 2021 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 0.21.1
  + This release adds the draft implementation of OGC API
  + Coverages support as well as numerous fixes to the codebase.
  + A full list of commits for 0.21.0 can be found at:
    https://github.com/geopython/OWSLib/commits/0.21.0
- packaging
  + Update copyright year
  + Sync list of Requires (pyproj > 2 and add pyyaml) with
    requirements
* Mon Dec  7 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 0.20.0
  + Provides initial support for draft OGC API - Records standard.
  + WFS: make wfs:FeatureTypeList optional for 1.1 and 2.0 (#673)
  + OGC API - Records: initial draft implementation (#679, #693)
  + WPS: add support for retrieving data from local filesystem (huard, #681)
  + WMTS: add support for boundingboxes (kordian-kowalski, #687)
  + Authentication: Enable switching off SSL verification (Samweli, #685)
* Mon Mar  2 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 0.19.1
  + Fixed Python 3.8 installation (#635, ocefpaf)
  + Refactored OGC API (#641, tomkralidis)
  + Add `python_requires` to prevent pip installing this on Python 2.x (#634, craigds)
  + Tests: use HEAD instead of GET in service_ok (#651, roel)
  + Tests: replaced service URLs with working versions (#648, roel)
  + WFS: Fix WFS get_schema when typename doubles as attributename (#647, roel)
  + WCS: Removed redundant check on logging level (#646, johanvdw)
  + WFS3: renamed time parameter to datetime (#639, mattfung)
  + WFS: Added required fields to wfs schema (#628, Alexandre27)
  + WCS: added resolution and size params to WCS GetCoverage requests (#633, dukestep)
  + DOCS: updated WMS docs (#649, pathmapper)
- update to version 0.19.0
  + ALL: python2 support removed (cehbrecht et. al.)
  + OWS
  - safeguard ProviderSite/@href (jannefleischer)
  - safeguard bbox parsing (walkermatt)
  + WMS: support ScaleDenominator
  + WMTS: add timeout (jachym)
  + OGC API Features updates following specification
  + TMS: fix broken constructor (justb4)
  + ALL: pass HTTP headers for WMS/WFS/WMTS/TMS (justb4)
  + ALL: test fixes/updates
- update to version 0.18.0
  + NEW: WFS 3 initial implementation
  + NEW: add Authentication framework (eric-spitler)
  + WPS:
  * add process properties, percentCompleted (cehbrecht)
  * add reference attributes (enolfc)
  * add support for multi process processes (huard)
  + OWS: add support for crs and dimension (saimeCS)
- packaging:
  + cleanup spec
  + move to build only python3
* Tue Mar  5 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.17.1 version
  * Fixed test-suite and converted doctests to unit-tests (#339).
  * Support for OWS Context (#483 thanks @allixender)
  * Support for WCS 2.0.0 and 2.0.1 (#430, thanks @doclements)
  * numerous bug-fixes, especially for WPS.
- Rename to python-OWSLib to match python package naming guidelines.
* Wed Jan 17 2018 bruno@ioda-net.ch
- Packaging : Move to singlespec + spec-cleaner (date,URL)
- Update to 0.16.0 version
  + drop Python 2.6 support
  + WFS: get schema auth params (karakostis)
  + WFS: add sortby to GetFeature requests (drnextgis)
  + CSW: add ows namespace to bounding box queries
  + CSW: add feature catalogue support parsing
  + CRS: support proj.4 CRS definitions (orhygine)
  + fix namespaces (jsanchezfr)
  + ISO GM03: fix bounding box handling
  0.15.0
  + WFS add doseq to WFS request qyery urlencode
  + WFS handle non-existing bounding boxes in feature types
  + SOS add support for authentication
  + WMTS add support for styles
  + ISO add support for gmd:locale
  + GM03 add support for GM03 ISO metadata profile
  + CRS catch invalid CRS codes
  + WMS fix time dimension handling in Capabilities
  + SWE various bug fixes
  + WPS fix WPS DescribeProcess issue on DataType
  fixed bbox lower/upper_corner conversion
  added a test for wps BoundingBoxDataInput
  added BoundingBoxDataInput and fix boundingbox parsing
  + Misc
  fix double '&&' in URL requests
  add util.clean_ows_url function to remove basic service
  parameters from OWS base URLs
  0.14.0
  + WFS: add authentication (@pmauduit)
  + WFS: fix parameter names for WFS2
  + OWS: implement updateSequence support
  + CSW: fix ref bug in CSW-T workflows
  + WCS: fix 1.0.0 Capabilities OWS namespace handling
* Wed Sep 28 2016 bruno@ioda-net.ch
- Update to 0.13.0
- Fix licence which is BSD-3-Clause
- Fix source url to new https and pypi.io schema
- Added requests as dependency
- Update Copyright year
* Sun Mar 13 2016 bruno@ioda-net.ch
- Update to 0.10.3
* Sun Oct 25 2015 bruno@ioda-net.ch
- Packaging :
  Add missing runtime require python(3)-pyproj
  Merge back the two package to one source build python3-owslib
  become a link to.
* Sat Oct 17 2015 bruno@ioda-net.ch
- Update to 0.9.2
* Thu Sep  3 2015 toddrme2178@gmail.com
- Shouldn't be noarch in SLE 11
* Tue Jun  9 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- updated to 0.8.13
* Sun Nov 30 2014 Angelos Tzotsos <tzotsos@opensuse.org>
- updated to 0.8.10
* Tue Feb  4 2014 Angelos Tzotsos <tzotsos@opensuse.org>
- updated to 0.8.6
* Tue Sep 10 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- added python-dateutil as required
* Thu Jun  6 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- updated to 0.7.2
* Sat Mar 30 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- updated to 0.7.1
* Wed Sep  5 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- updated to 0.5.1
* Thu Jun 21 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- fixed CentOS, RedHat and Scientific Linux builds
* Thu Jun 21 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- initial release 0.5.0
